@@ -12,7 +12,7 @@ def encrypt(text, cipher_key=None):
     :param cipher_key: 加密key
     :return: 加密后的文本
     """
-    if cipher_key is None:
+    if cipher_key is None or text is None:
         return text
     cipher = Fernet(bytes(cipher_key, encoding="utf8"))
     return cipher.encrypt(text.encode()).decode()
@@ -25,7 +25,10 @@ def decrypt(encrypted_text, cipher_key=None):
     :param encrypted_text: 需要解密的文本
     :return:解密后的文本
     """
-    if cipher_key is None:
+    if cipher_key is None or encrypted_text is None:
         return encrypted_text
     cipher = Fernet(bytes(cipher_key, encoding="utf8"))
-    return cipher.decrypt(bytes(encrypted_text, encoding='utf8')).decode()
+    try:
+        return cipher.decrypt(bytes(encrypted_text, encoding='utf8')).decode()
+    except Exception as e:
+        return encrypted_text
